@@ -1,15 +1,15 @@
-"""
-Class and logic that create an abstract scene.
-"""
+"""The scene module contains classes and methods \
+relating to an activity scene."""
 from typing import Callable, List
 from cvgui.core.displaying.components import Component
 
 
 class Scene:
-    """A related group of components that should
+    """A related group of components that should \
     be rendered at the same time."""
 
     def __init__(self) -> None:
+        """Create a new scene."""
         self.components: List[Component] = []
         """Components to be included in the scene."""
 
@@ -17,7 +17,7 @@ class Scene:
         """Function to run every frame."""
 
     def add_component(self, component: Component) -> None:
-        """Adds a component to the list of components for
+        """Add a component to the list of components for \
         the scene.
 
         Args:
